/**
 * Copyright (c) 2013-2017 Lorenzo Bettini.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   Lorenzo Bettini - Initial contribution and API
 */
package org.eclipse.xsemantics.dsl.ui.labeling;

import com.google.inject.Inject;
import org.eclipse.emf.edit.ui.provider.AdapterFactoryLabelProvider;
import org.eclipse.xsemantics.dsl.util.XsemanticsUtils;
import org.eclipse.xsemantics.dsl.xsemantics.AbstractFieldDefinition;
import org.eclipse.xsemantics.dsl.xsemantics.AuxiliaryDescription;
import org.eclipse.xsemantics.dsl.xsemantics.AuxiliaryFunction;
import org.eclipse.xsemantics.dsl.xsemantics.Axiom;
import org.eclipse.xsemantics.dsl.xsemantics.CheckRule;
import org.eclipse.xsemantics.dsl.xsemantics.JudgmentDescription;
import org.eclipse.xsemantics.dsl.xsemantics.Rule;
import org.eclipse.xsemantics.dsl.xsemantics.RuleWithPremises;
import org.eclipse.xsemantics.dsl.xsemantics.XsemanticsSystem;
import org.eclipse.xtext.util.Strings;
import org.eclipse.xtext.xbase.lib.Extension;
import org.eclipse.xtext.xbase.ui.labeling.XbaseLabelProvider;

/**
 * Provides labels for a EObjects.
 * 
 * see http://www.eclipse.org/Xtext/documentation.html#labelProvider
 */
@SuppressWarnings("all")
public class XsemanticsLabelProvider extends XbaseLabelProvider {
  @Inject
  @Extension
  private XsemanticsUtils _xsemanticsUtils;
  
  @Inject
  public XsemanticsLabelProvider(final AdapterFactoryLabelProvider delegate) {
    super(delegate);
  }
  
  public String text(final Rule rule) {
    final JudgmentDescription judgmentDescription = this._xsemanticsUtils.getJudgmentDescription(rule);
    if ((judgmentDescription == null)) {
      return rule.getName();
    }
    String _name = rule.getName();
    String _plus = (_name + " (");
    String _emptyIfNull = Strings.emptyIfNull(judgmentDescription.getName());
    String _plus_1 = (_plus + _emptyIfNull);
    return (_plus_1 + ")");
  }
  
  public String text(final CheckRule rule) {
    return rule.getName();
  }
  
  public String text(final AuxiliaryFunction aux) {
    final AuxiliaryDescription desc = this._xsemanticsUtils.getAuxiliaryDescription(aux);
    if ((desc == null)) {
      return aux.getName();
    }
    String _name = aux.getName();
    String _plus = (_name + " (");
    String _emptyIfNull = Strings.emptyIfNull(desc.getName());
    String _plus_1 = (_plus + _emptyIfNull);
    return (_plus_1 + ")");
  }
  
  public String image(final Axiom axiom) {
    return "axiom.gif";
  }
  
  public String image(final RuleWithPremises rule) {
    return "rule.gif";
  }
  
  public String image(final CheckRule rule) {
    return "checkrule.gif";
  }
  
  public String image(final XsemanticsSystem ts) {
    return "system.gif";
  }
  
  public String image(final JudgmentDescription desc) {
    return "judgment.gif";
  }
  
  public String image(final AuxiliaryFunction aux) {
    return "auxfun.gif";
  }
  
  public String image(final AuxiliaryDescription aux) {
    return "auxdesc.gif";
  }
  
  public String image(final AbstractFieldDefinition f) {
    return "field_public_obj.gif";
  }
}
